mailr19045 - in /trunk: lib/algebra/ test_suite/unit_tests/_lib/_algebra/


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on March 23, 2013 - 09:41:
Author: bugman
Date: Sat Mar 23 09:41:28 2013
New Revision: 19045

URL: http://svn.gna.org/viewcvs/relax?rev=19045&view=rev
Log:
Created the empty lib.algebra package - this is for advanced linear algebra 
not present in numpy.


Added:
    trunk/lib/algebra/
    trunk/lib/algebra/__init__.py
    trunk/test_suite/unit_tests/_lib/_algebra/
    trunk/test_suite/unit_tests/_lib/_algebra/__init__.py
      - copied unchanged from r19037, 
trunk/test_suite/unit_tests/_lib/_auto_relaxation/__init__.py
    trunk/test_suite/unit_tests/_lib/_algebra/test___init__.py
      - copied, changed from r19037, 
trunk/test_suite/unit_tests/_lib/_auto_relaxation/test___init__.py

Added: trunk/lib/algebra/__init__.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/lib/algebra/__init__.py?rev=19045&view=auto
==============================================================================
--- trunk/lib/algebra/__init__.py (added)
+++ trunk/lib/algebra/__init__.py Sat Mar 23 09:41:28 2013
@@ -1,0 +1,27 @@
+###############################################################################
+#                                                                            
 #
+# Copyright (C) 2013 Edward d'Auvergne                                       
 #
+#                                                                            
 #
+# This file is part of the program relax (http://www.nmr-relax.com).         
 #
+#                                                                            
 #
+# This program is free software: you can redistribute it and/or modify       
 #
+# it under the terms of the GNU General Public License as published by       
 #
+# the Free Software Foundation, either version 3 of the License, or          
 #
+# (at your option) any later version.                                        
 #
+#                                                                            
 #
+# This program is distributed in the hope that it will be useful,            
 #
+# but WITHOUT ANY WARRANTY; without even the implied warranty of             
 #
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              
 #
+# GNU General Public License for more details.                               
 #
+#                                                                            
 #
+# You should have received a copy of the GNU General Public License          
 #
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.      
 #
+#                                                                            
 #
+###############################################################################
+
+# Package docstring.
+"""The relax-lib NMR package - a library of functions for advanced linear 
algebra not present in numpy."""
+
+__all__ = [
+    ''
+]

Copied: trunk/test_suite/unit_tests/_lib/_algebra/test___init__.py (from 
r19037, trunk/test_suite/unit_tests/_lib/_auto_relaxation/test___init__.py)
URL: 
http://svn.gna.org/viewcvs/relax/trunk/test_suite/unit_tests/_lib/_algebra/test___init__.py?p2=trunk/test_suite/unit_tests/_lib/_algebra/test___init__.py&p1=trunk/test_suite/unit_tests/_lib/_auto_relaxation/test___init__.py&r1=19037&r2=19045&rev=19045&view=diff
==============================================================================
--- trunk/test_suite/unit_tests/_lib/_auto_relaxation/test___init__.py 
(original)
+++ trunk/test_suite/unit_tests/_lib/_algebra/test___init__.py Sat Mar 23 
09:41:28 2013
@@ -29,11 +29,11 @@
 
 
 class Test___init__(PackageTestCase):
     """Unit tests for the lib.auto_relaxation package."""
 
     def setUp(self):
         """Set up for the package checking."""
 
-        self.package = lib.auto_relaxation
-        self.package_name = 'lib.auto_relaxation'
-        self.package_path = sys.path[0] + sep + 'lib' + sep + 
'auto_relaxation'
+        self.package = lib.algebra
+        self.package_name = 'lib.algebra'
+        self.package_path = sys.path[0] + sep + 'lib' + sep + 'algebra'
@@ -29,11 +29,11 @@
 
 class Test___init__(PackageTestCase):
-    """Unit tests for the lib.auto_relaxation package."""
+    """Unit tests for the lib.algebra package."""
 
     def setUp(self):




Related Messages


Powered by MHonArc, Updated Sat Mar 23 10:00:02 2013